@@ -23,46 +23,41 @@ from aliyunsdkdyplsapi.endpoint import endpoint_data
 class QueryCallStatusRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'QueryCallStatus','dypls')
+		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'QueryCallStatus')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_SubsId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_SubsId(self): # String
 		return self.get_query_params().get('SubsId')
 
-	def set_SubsId(self,SubsId):
-		self.add_query_param('SubsId',SubsId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_SubsId(self, SubsId):  # String
+		self.add_query_param('SubsId', SubsId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_CallNo(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_CallNo(self): # String
 		return self.get_query_params().get('CallNo')
 
-	def set_CallNo(self,CallNo):
-		self.add_query_param('CallNo',CallNo)
-
-	def get_OwnerId(self):
+	def set_CallNo(self, CallNo):  # String
+		self.add_query_param('CallNo', CallNo)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_PoolKey(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_PoolKey(self): # String
 		return self.get_query_params().get('PoolKey')
 
-	def set_PoolKey(self,PoolKey):
-		self.add_query_param('PoolKey',PoolKey)
\ No newline at end of file
+	def set_PoolKey(self, PoolKey):  # String
+		self.add_query_param('PoolKey', PoolKey)
